Class: Google::Analytics::Admin::V1alpha::DataRedactionSettings
- Inherits:
-
Object
- Object
- Google::Analytics::Admin::V1alpha::DataRedactionSettings
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/analytics/admin/v1alpha/resources.rb
Overview
Settings for client-side data redaction. Singleton resource under a Web Stream.
Instance Attribute Summary collapse
-
#email_redaction_enabled ⇒ ::Boolean
If enabled, any event parameter or user property values that look like an email will be redacted.
-
#name ⇒ ::String
readonly
Output only.
-
#query_parameter_keys ⇒ ::Array<::String>
The query parameter keys to apply redaction logic to if present in the URL.
-
#query_parameter_redaction_enabled ⇒ ::Boolean
Query Parameter redaction removes the key and value portions of a query parameter if it is in the configured set of query parameters.
Instance Attribute Details
#email_redaction_enabled ⇒ ::Boolean
1626 1627 1628 1629 |
# File 'proto_docs/google/analytics/admin/v1alpha/resources.rb', line 1626 class DataRedactionSettings include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#name ⇒ ::String (readonly)
1626 1627 1628 1629 |
# File 'proto_docs/google/analytics/admin/v1alpha/resources.rb', line 1626 class DataRedactionSettings include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#query_parameter_keys ⇒ ::Array<::String>
1626 1627 1628 1629 |
# File 'proto_docs/google/analytics/admin/v1alpha/resources.rb', line 1626 class DataRedactionSettings include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#query_parameter_redaction_enabled ⇒ ::Boolean
1626 1627 1628 1629 |
# File 'proto_docs/google/analytics/admin/v1alpha/resources.rb', line 1626 class DataRedactionSettings include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |