Class: Google::Analytics::Admin::V1alpha::DataRetentionSettings
- Inherits:
-
Object
- Object
- Google::Analytics::Admin::V1alpha::DataRetentionSettings
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/analytics/admin/v1alpha/resources.rb
Overview
Settings values for data retention. This is a singleton resource.
Defined Under Namespace
Modules: RetentionDuration
Instance Attribute Summary collapse
-
#event_data_retention ⇒ ::Google::Analytics::Admin::V1alpha::DataRetentionSettings::RetentionDuration
Required.
-
#name ⇒ ::String
Identifier.
-
#reset_user_data_on_new_activity ⇒ ::Boolean
If true, reset the retention period for the user identifier with every event from that user.
-
#user_data_retention ⇒ ::Google::Analytics::Admin::V1alpha::DataRetentionSettings::RetentionDuration
Required.
Instance Attribute Details
#event_data_retention ⇒ ::Google::Analytics::Admin::V1alpha::DataRetentionSettings::RetentionDuration
Returns Required. The length of time that event-level data is retained.
1333 1334 1335 1336 1337 1338 1339 1340 1341 1342 1343 1344 1345 1346 1347 1348 1349 1350 1351 1352 1353 1354 1355 1356 1357 1358 1359 1360 |
# File 'proto_docs/google/analytics/admin/v1alpha/resources.rb', line 1333 class DataRetentionSettings include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Valid values for the data retention duration. module RetentionDuration # Data retention time duration is not specified. RETENTION_DURATION_UNSPECIFIED = 0 # The data retention time duration is 2 months. TWO_MONTHS = 1 # The data retention time duration is 14 months. FOURTEEN_MONTHS = 3 # The data retention time duration is 26 months. # Available to 360 properties only. Available for event data only. TWENTY_SIX_MONTHS = 4 # The data retention time duration is 38 months. # Available to 360 properties only. Available for event data only. THIRTY_EIGHT_MONTHS = 5 # The data retention time duration is 50 months. # Available to 360 properties only. Available for event data only. FIFTY_MONTHS = 6 end end |
#name ⇒ ::String
Returns Identifier. Resource name for this DataRetentionSetting resource. Format: properties/{property}/dataRetentionSettings.
1333 1334 1335 1336 1337 1338 1339 1340 1341 1342 1343 1344 1345 1346 1347 1348 1349 1350 1351 1352 1353 1354 1355 1356 1357 1358 1359 1360 |
# File 'proto_docs/google/analytics/admin/v1alpha/resources.rb', line 1333 class DataRetentionSettings include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Valid values for the data retention duration. module RetentionDuration # Data retention time duration is not specified. RETENTION_DURATION_UNSPECIFIED = 0 # The data retention time duration is 2 months. TWO_MONTHS = 1 # The data retention time duration is 14 months. FOURTEEN_MONTHS = 3 # The data retention time duration is 26 months. # Available to 360 properties only. Available for event data only. TWENTY_SIX_MONTHS = 4 # The data retention time duration is 38 months. # Available to 360 properties only. Available for event data only. THIRTY_EIGHT_MONTHS = 5 # The data retention time duration is 50 months. # Available to 360 properties only. Available for event data only. FIFTY_MONTHS = 6 end end |
#reset_user_data_on_new_activity ⇒ ::Boolean
Returns If true, reset the retention period for the user identifier with every event from that user.
1333 1334 1335 1336 1337 1338 1339 1340 1341 1342 1343 1344 1345 1346 1347 1348 1349 1350 1351 1352 1353 1354 1355 1356 1357 1358 1359 1360 |
# File 'proto_docs/google/analytics/admin/v1alpha/resources.rb', line 1333 class DataRetentionSettings include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Valid values for the data retention duration. module RetentionDuration # Data retention time duration is not specified. RETENTION_DURATION_UNSPECIFIED = 0 # The data retention time duration is 2 months. TWO_MONTHS = 1 # The data retention time duration is 14 months. FOURTEEN_MONTHS = 3 # The data retention time duration is 26 months. # Available to 360 properties only. Available for event data only. TWENTY_SIX_MONTHS = 4 # The data retention time duration is 38 months. # Available to 360 properties only. Available for event data only. THIRTY_EIGHT_MONTHS = 5 # The data retention time duration is 50 months. # Available to 360 properties only. Available for event data only. FIFTY_MONTHS = 6 end end |
#user_data_retention ⇒ ::Google::Analytics::Admin::V1alpha::DataRetentionSettings::RetentionDuration
Returns Required. The length of time that user-level data is retained.
1333 1334 1335 1336 1337 1338 1339 1340 1341 1342 1343 1344 1345 1346 1347 1348 1349 1350 1351 1352 1353 1354 1355 1356 1357 1358 1359 1360 |
# File 'proto_docs/google/analytics/admin/v1alpha/resources.rb', line 1333 class DataRetentionSettings include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Valid values for the data retention duration. module RetentionDuration # Data retention time duration is not specified. RETENTION_DURATION_UNSPECIFIED = 0 # The data retention time duration is 2 months. TWO_MONTHS = 1 # The data retention time duration is 14 months. FOURTEEN_MONTHS = 3 # The data retention time duration is 26 months. # Available to 360 properties only. Available for event data only. TWENTY_SIX_MONTHS = 4 # The data retention time duration is 38 months. # Available to 360 properties only. Available for event data only. THIRTY_EIGHT_MONTHS = 5 # The data retention time duration is 50 months. # Available to 360 properties only. Available for event data only. FIFTY_MONTHS = 6 end end |