Class: Google::Analytics::Admin::V1alpha::ListConversionEventsRequest

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/analytics/admin/v1alpha/analytics_admin.rb

Overview

Request message for ListConversionEvents RPC

Instance Attribute Summary collapse

Instance Attribute Details

#page_size::Integer

Returns Optional. The maximum number of resources to return. If unspecified, at most 50 resources will be returned. The maximum value is 200; (higher values will be coerced to the maximum).

Returns:

  • (::Integer)

    Optional. The maximum number of resources to return. If unspecified, at most 50 resources will be returned. The maximum value is 200; (higher values will be coerced to the maximum)



901
902
903
904
# File 'proto_docs/google/analytics/admin/v1alpha/analytics_admin.rb', line 901

class ListConversionEventsRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#page_token::String

Returns Optional. A page token, received from a previous ListConversionEvents call. Provide this to retrieve the subsequent page. When paginating, all other parameters provided to ListConversionEvents must match the call that provided the page token.

Returns:

  • (::String)

    Optional. A page token, received from a previous ListConversionEvents call. Provide this to retrieve the subsequent page. When paginating, all other parameters provided to ListConversionEvents must match the call that provided the page token.



901
902
903
904
# File 'proto_docs/google/analytics/admin/v1alpha/analytics_admin.rb', line 901

class ListConversionEventsRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#parent::String

Returns Required. The resource name of the parent property. Example: 'properties/123'.

Returns:

  • (::String)

    Required. The resource name of the parent property. Example: 'properties/123'



901
902
903
904
# File 'proto_docs/google/analytics/admin/v1alpha/analytics_admin.rb', line 901

class ListConversionEventsRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end