Class: Google::Analytics::Admin::V1alpha::ListKeyEventsRequest

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/analytics/admin/v1alpha/analytics_admin.rb

Overview

Request message for ListKeyEvents RPC

Instance Attribute Summary collapse

Instance Attribute Details

#page_size::Integer

Returns Optional. The maximum number of resources to return. If unspecified, at most 50 resources will be returned. The maximum value is 200; (higher values will be coerced to the maximum).

Returns:

  • (::Integer)

    Optional. The maximum number of resources to return. If unspecified, at most 50 resources will be returned. The maximum value is 200; (higher values will be coerced to the maximum)



986
987
988
989
# File 'proto_docs/google/analytics/admin/v1alpha/analytics_admin.rb', line 986

class ListKeyEventsRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#page_token::String

Returns Optional. A page token, received from a previous ListKeyEvents call. Provide this to retrieve the subsequent page. When paginating, all other parameters provided to ListKeyEvents must match the call that provided the page token.

Returns:

  • (::String)

    Optional. A page token, received from a previous ListKeyEvents call. Provide this to retrieve the subsequent page. When paginating, all other parameters provided to ListKeyEvents must match the call that provided the page token.



986
987
988
989
# File 'proto_docs/google/analytics/admin/v1alpha/analytics_admin.rb', line 986

class ListKeyEventsRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#parent::String

Returns Required. The resource name of the parent property. Example: 'properties/123'.

Returns:

  • (::String)

    Required. The resource name of the parent property. Example: 'properties/123'



986
987
988
989
# File 'proto_docs/google/analytics/admin/v1alpha/analytics_admin.rb', line 986

class ListKeyEventsRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end