Class: Google::Analytics::Admin::V1alpha::ListMeasurementProtocolSecretsRequest

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/analytics/admin/v1alpha/analytics_admin.rb

Overview

Request message for ListMeasurementProtocolSecret RPC

Instance Attribute Summary collapse

Instance Attribute Details

#page_size::Integer

Returns Optional. The maximum number of resources to return. If unspecified, at most 10 resources will be returned. The maximum value is 10. Higher values will be coerced to the maximum.

Returns:

  • (::Integer)

    Optional. The maximum number of resources to return. If unspecified, at most 10 resources will be returned. The maximum value is 10. Higher values will be coerced to the maximum.



700
701
702
703
# File 'proto_docs/google/analytics/admin/v1alpha/analytics_admin.rb', line 700

class ListMeasurementProtocolSecretsRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#page_token::String

Returns Optional. A page token, received from a previous ListMeasurementProtocolSecrets call. Provide this to retrieve the subsequent page. When paginating, all other parameters provided to ListMeasurementProtocolSecrets must match the call that provided the page token.

Returns:

  • (::String)

    Optional. A page token, received from a previous ListMeasurementProtocolSecrets call. Provide this to retrieve the subsequent page. When paginating, all other parameters provided to ListMeasurementProtocolSecrets must match the call that provided the page token.



700
701
702
703
# File 'proto_docs/google/analytics/admin/v1alpha/analytics_admin.rb', line 700

class ListMeasurementProtocolSecretsRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#parent::String

Returns Required. The resource name of the parent stream. Format: properties/{property}/dataStreams/{dataStream}/measurementProtocolSecrets.

Returns:

  • (::String)

    Required. The resource name of the parent stream. Format: properties/{property}/dataStreams/{dataStream}/measurementProtocolSecrets



700
701
702
703
# File 'proto_docs/google/analytics/admin/v1alpha/analytics_admin.rb', line 700

class ListMeasurementProtocolSecretsRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end