Class: Google::Analytics::Admin::V1alpha::ListSKAdNetworkConversionValueSchemasResponse

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/analytics/admin/v1alpha/analytics_admin.rb

Overview

Response message for ListSKAdNetworkConversionValueSchemas RPC

Instance Attribute Summary collapse

Instance Attribute Details

#next_page_token::String

Returns A token, which can be sent as page_token to retrieve the next page. If this field is omitted, there are no subsequent pages. Currently, Google Analytics supports only one SKAdNetworkConversionValueSchema per dataStream, so this will never be populated.

Returns:

  • (::String)

    A token, which can be sent as page_token to retrieve the next page. If this field is omitted, there are no subsequent pages. Currently, Google Analytics supports only one SKAdNetworkConversionValueSchema per dataStream, so this will never be populated.



803
804
805
806
# File 'proto_docs/google/analytics/admin/v1alpha/analytics_admin.rb', line 803

class ListSKAdNetworkConversionValueSchemasResponse
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#skadnetwork_conversion_value_schemas::Array<::Google::Analytics::Admin::V1alpha::SKAdNetworkConversionValueSchema>

Returns List of SKAdNetworkConversionValueSchemas. This will have at most one value.

Returns:



803
804
805
806
# File 'proto_docs/google/analytics/admin/v1alpha/analytics_admin.rb', line 803

class ListSKAdNetworkConversionValueSchemasResponse
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end