Class: Google::Analytics::Admin::V1alpha::MeasurementProtocolSecret

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/analytics/admin/v1alpha/resources.rb

Overview

A secret value used for sending hits to Measurement Protocol.

Instance Attribute Summary collapse

Instance Attribute Details

#display_name ⇒ ::String

Returns Required. Human-readable display name for this secret.

Returns:

  • (::String) —

    Required. Human-readable display name for this secret.



394
395
396
397
# File 'proto_docs/google/analytics/admin/v1alpha/resources.rb', line 394

class MeasurementProtocolSecret
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#name ⇒ ::String (readonly)

Returns Output only. Resource name of this secret. This secret may be a child of any type of stream. Format: properties/{property}/dataStreams/{dataStream}/measurementProtocolSecrets/{measurementProtocolSecret}.

Returns:

  • (::String) —

    Output only. Resource name of this secret. This secret may be a child of any type of stream. Format: properties/{property}/dataStreams/{dataStream}/measurementProtocolSecrets/{measurementProtocolSecret}



394
395
396
397
# File 'proto_docs/google/analytics/admin/v1alpha/resources.rb', line 394

class MeasurementProtocolSecret
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#secret_value ⇒ ::String (readonly)

Returns Output only. The measurement protocol secret value. Pass this value to the api_secret field of the Measurement Protocol API when sending hits to this secret's parent property.

Returns:

  • (::String) —

    Output only. The measurement protocol secret value. Pass this value to the api_secret field of the Measurement Protocol API when sending hits to this secret's parent property.



394
395
396
397
# File 'proto_docs/google/analytics/admin/v1alpha/resources.rb', line 394

class MeasurementProtocolSecret
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end