Class: Google::Analytics::Admin::V1alpha::PropertySummary
- Inherits:
-
Object
- Object
- Google::Analytics::Admin::V1alpha::PropertySummary
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/analytics/admin/v1alpha/resources.rb
Overview
A virtual resource representing metadata for a Google Analytics property.
Instance Attribute Summary collapse
-
#can_edit ⇒ ::Boolean
If true, then the user has a Google Analytics role that permits them to edit the property.
-
#display_name ⇒ ::String
Display name for the property referred to in this property summary.
-
#parent ⇒ ::String
Resource name of this property's logical parent.
-
#property ⇒ ::String
Resource name of property referred to by this property summary Format: properties/{property_id} Example: "properties/1000".
-
#property_type ⇒ ::Google::Analytics::Admin::V1alpha::PropertyType
The property's property type.
Instance Attribute Details
#can_edit ⇒ ::Boolean
Returns If true, then the user has a Google Analytics role that permits them to edit the property.
405 406 407 408 |
# File 'proto_docs/google/analytics/admin/v1alpha/resources.rb', line 405 class PropertySummary include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#display_name ⇒ ::String
Returns Display name for the property referred to in this property summary.
405 406 407 408 |
# File 'proto_docs/google/analytics/admin/v1alpha/resources.rb', line 405 class PropertySummary include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#parent ⇒ ::String
Returns Resource name of this property's logical parent.
Note: The Property-Moving UI can be used to change the parent. Format: accounts/{account}, properties/{property} Example: "accounts/100", "properties/200".
405 406 407 408 |
# File 'proto_docs/google/analytics/admin/v1alpha/resources.rb', line 405 class PropertySummary include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#property ⇒ ::String
Returns Resource name of property referred to by this property summary Format: properties/{property_id} Example: "properties/1000".
405 406 407 408 |
# File 'proto_docs/google/analytics/admin/v1alpha/resources.rb', line 405 class PropertySummary include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#property_type ⇒ ::Google::Analytics::Admin::V1alpha::PropertyType
Returns The property's property type.
405 406 407 408 |
# File 'proto_docs/google/analytics/admin/v1alpha/resources.rb', line 405 class PropertySummary include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |