Class: Google::Analytics::Admin::V1alpha::SubmitUserDeletionResponse
- Inherits:
-
Object
- Object
- Google::Analytics::Admin::V1alpha::SubmitUserDeletionResponse
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/analytics/admin/v1alpha/analytics_admin.rb
Overview
Response message for SubmitUserDeletion RPC.
Instance Attribute Summary collapse
-
#deletion_request_time ⇒ ::Google::Protobuf::Timestamp
Marks the moment for which all visitor data before this point should be deleted.
Instance Attribute Details
#deletion_request_time ⇒ ::Google::Protobuf::Timestamp
Returns Marks the moment for which all visitor data before this point should be deleted. This is set to the time at which the deletion request was received.
2878 2879 2880 2881 |
# File 'proto_docs/google/analytics/admin/v1alpha/analytics_admin.rb', line 2878 class SubmitUserDeletionResponse include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |