Class: Google::Analytics::Admin::V1alpha::UserProvidedDataSettings

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/analytics/admin/v1alpha/resources.rb

Overview

Configuration for user-provided data collection. This is a singleton resource for a Google Analytics property.

Instance Attribute Summary collapse

Instance Attribute Details

#automatically_detected_data_collection_enabled::Boolean

Returns Optional. Whether this property allows a Google Tag to automatically collect user-provided data from your website. This setting only takes effect if user_provided_data_collection_enabled is also true.

Returns:

  • (::Boolean)

    Optional. Whether this property allows a Google Tag to automatically collect user-provided data from your website. This setting only takes effect if user_provided_data_collection_enabled is also true.



1842
1843
1844
1845
# File 'proto_docs/google/analytics/admin/v1alpha/resources.rb', line 1842

class UserProvidedDataSettings
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#name::String

Returns Identifier. Resource name of this setting. Format: properties/{property}/userProvidedDataSettings Example: "properties/1000/userProvidedDataSettings".

Returns:

  • (::String)

    Identifier. Resource name of this setting. Format: properties/{property}/userProvidedDataSettings Example: "properties/1000/userProvidedDataSettings"



1842
1843
1844
1845
# File 'proto_docs/google/analytics/admin/v1alpha/resources.rb', line 1842

class UserProvidedDataSettings
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#user_provided_data_collection_enabled::Boolean

Returns Optional. Whether this property accepts user-provided data sent to it.

Returns:

  • (::Boolean)

    Optional. Whether this property accepts user-provided data sent to it.



1842
1843
1844
1845
# File 'proto_docs/google/analytics/admin/v1alpha/resources.rb', line 1842

class UserProvidedDataSettings
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end