Class: Google::Api::BatchingConfigProto
- Inherits:
-
Object
- Object
- Google::Api::BatchingConfigProto
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/api/client.rb
Overview
BatchingConfigProto defines the batching configuration for an API method.
Instance Attribute Summary collapse
-
#batch_descriptor ⇒ ::Google::Api::BatchingDescriptorProto
The request and response fields used in batching.
-
#thresholds ⇒ ::Google::Api::BatchingSettingsProto
The thresholds which trigger a batched request to be sent.
Instance Attribute Details
#batch_descriptor ⇒ ::Google::Api::BatchingDescriptorProto
Returns The request and response fields used in batching.
468 469 470 471 |
# File 'proto_docs/google/api/client.rb', line 468 class BatchingConfigProto include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#thresholds ⇒ ::Google::Api::BatchingSettingsProto
Returns The thresholds which trigger a batched request to be sent.
468 469 470 471 |
# File 'proto_docs/google/api/client.rb', line 468 class BatchingConfigProto include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |