Class: Google::Analytics::Admin::V1alpha::UpdateReportingIdentitySettingsRequest
- Inherits:
-
Object
- Object
- Google::Analytics::Admin::V1alpha::UpdateReportingIdentitySettingsRequest
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/analytics/admin/v1alpha/analytics_admin.rb
Overview
Request message for UpdateReportingIdentitySettings RPC.
Instance Attribute Summary collapse
-
#reporting_identity_settings ⇒ ::Google::Analytics::Admin::V1alpha::ReportingIdentitySettings
Required.
-
#update_mask ⇒ ::Google::Protobuf::FieldMask
Optional.
Instance Attribute Details
#reporting_identity_settings ⇒ ::Google::Analytics::Admin::V1alpha::ReportingIdentitySettings
Returns Required. The reporting identity settings to update.
The settings' name field is used to identify the settings.
2971 2972 2973 2974 |
# File 'proto_docs/google/analytics/admin/v1alpha/analytics_admin.rb', line 2971 class UpdateReportingIdentitySettingsRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#update_mask ⇒ ::Google::Protobuf::FieldMask
Returns Optional. The list of fields to be updated. Field names must be in snake case (for example, "field_to_update"). Omitted fields will not be updated. To replace the entire entity, use one path with the string "*" to match all fields. If omitted, the service will treat it as an implied field mask equivalent to all fields that are populated.
2971 2972 2973 2974 |
# File 'proto_docs/google/analytics/admin/v1alpha/analytics_admin.rb', line 2971 class UpdateReportingIdentitySettingsRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |